PySkein 0.3.1 — PySkein v0.3.1 documentation

### Navigation

- index
- next |
- PySkein v0.3.1 documentation »

# PySkein 0.3.1

PySkein is an extension module for Python 3.0 or later providing the Skein hash algorithms (c.f. Skein website). It is based on the optimized version of the reference implementation written in C by Doug Whiting, allowing efficient hash computations. (On a 2.8 GHz Opteron I get a hashing performance of 373 MB/s for Skein-512-512 as called from Python.)

- Computing Skein hashes
  - Examples

- Threefish encryption
  - Examples

- Demo Scripts
  - skeinsum
  - threefish

- Download PySkein
  - Previous versions

### Navigation

- index
- next |
- PySkein v0.3.1 documentation »